@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2006..2024 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2006..2025 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +24,8 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2006..2024 @BABOLO http://www.babolo.ru/\n"
-#ident "@(#) $Id: lexor.c,v 1.38 2024/01/07 23:27:17 babolo Exp $\n"
+#ident "@(#) Copyright (C)2006..2025 @BABOLO http://www.babolo.ru/\n"
+#ident "@(#) $Id: lexor.c,v 1.44 2025/12/21 18:17:48 babolo Exp $\n"
 
 #define BLIN_COMPAT  4
 #define MULAR_COMPAT 0
@@ -178,7 +178,7 @@ argrun(runparm *r, run12parm *r2, int argc, char **argv) {
         r2->ccarg[r2->ccarp++] = "/dev/stdout";
         r2->ccarg[r2->ccarp] = NULL;
         ifBLIN_QO1 {
-            for (u_int32_t i = 0; r2->ccarg[i] && i < r2->ccarp; i++) {
+            for (u_int32_t i = 0; (i < r2->ccarp) && !!r2->ccarg[i]; i++) {
                 ifBLIN_QX1("%d=%s~", i, r2->ccarg[i]);
             }
             ifBLIN_QX1("in=%s~", r2->infn);
@@ -220,7 +220,7 @@ static babolo_lexor bylex =
 }};
 
 static babolo_lexor bytree =
-{ (const u_char*)
+{ (const u_char *)
   "0000""0000""3200""0000"
   "0000""0000""0000""0000"
   "3000""4000""4440""1000"
@@ -298,7 +298,7 @@ run1(runparm *r, run12parm *r2) {
         ;       ex = EX_DATAERR;
         ;       goto out;
         ;   }
-        ;   i = babolo_goword(&bylex, &ingo);
+        ;   i = babolo_goword(&bylex, (const char **)&ingo);
         ;   ++line;
         ;   if  (i == 0) {
         ;       ifBLIN_QX0("No work #1");
@@ -329,7 +329,7 @@ run1(runparm *r, run12parm *r2) {
         r2->inflag = NULL;
         for (inwent = ingo; ;inwent = ingo) {
             u_int32_t i;
-        ;   i = babolo_goword(&bytree, &ingo);
+        ;   i = babolo_goword(&bytree, (const char **)&ingo);
         ;   if  (!i) {
         ;       ifBLIN_QW0("No work #2");
         ;       ex = EX_DATAERR;
@@ -429,7 +429,10 @@ run1(runparm *r, run12parm *r2) {
                     babolo_parm **p;
         ;           ifBLIN_QO1 {
         ;               fprintf( stderr, "%lu..%u 0=%s~ 1=%s~"
-                               , (line - parm->cntr), line, parm->argv[0], parm->argv[1]
+                               , (unsigned long)(line - parm->cntr)
+                               , line
+                               , parm->argv[0]
+                               , parm->argv[1]
                                );
         ;               if  (parm->argc > 2) fprintf(stderr, " 2=%s~", parm->argv[2]);
         ;               if  (parm->argc > 3) fprintf(stderr, " 3=%s~", parm->argv[3]);
@@ -508,40 +511,44 @@ intrfil1(runparm *r, run12parm *r2) {
 # define blin_internal_flags (r->flags & BLIN_MASK)
     FILE         *sto;
     int           ex = EX_OK;
-    babolo_parm **c;
-    const char   *s;
 
     ifBLIN_QX3("+");
     if  (!(sto = fdopen(r2->fil1, "w"))) {
         ifBLIN_QW0("fdopen #110");
         ex = EX_IOERR;
     } else {
+        babolo_parm **c;
+        const char   *s;
+
         if  (r2->ininc) fprintf(sto, "#line %u \"%s\"\n%s", (u_int)r2->lninc, r2->infn, r2->ininc);
         if  (r2->incopy) fprintf(sto, "#line %u \"%s\"\n%s", (u_int)r2->lncopy, r2->infn, r2->incopy);
-        fprintf( sto, "struct {\n"
-                      "    u_int32_t f;\n"
-                      "    u_int32_t n;\n"
-                      "    u_char t[256];\n"
-                      "    u_int32_t v[%u];\n"
-                      "    u_char e[%u];\n"
-               , (u_int)r2->imd->top.index, (u_int)r2->imd->top.index
+        fprintf( sto
+               , "struct {\n"
+                 "    u_int32_t    f;\n"
+                 "    u_int32_t    n;\n"
+                 "    const u_char t[256];\n"
+                 "    u_int32_t    v[%u];\n"
+                 "    const u_char e[%u];\n"
+               , (u_int)r2->imd->top.index
+               , (u_int)r2->imd->top.index
                );
         ifBLIN_QX2( "struct {\n"
-                    "    u_int32_t f;\n"
-                    "    u_int32_t c;\n"
-                    "    u_char t[256];\n"
-                    "    u_int32_t v[%u];\n"
-                    "    u_char e[%u];\n"
-                  , (u_int)r2->imd->top.index, (u_int)r2->imd->top.index
+                    "    u_int32_t    f;\n"
+                    "    u_int32_t    c;\n"
+                    "    const u_char t[256];\n"
+                    "    u_int32_t    v[%u];\n"
+                    "    const u_char e[%u];"
+                  , (u_int)r2->imd->top.index
+                  , (u_int)r2->imd->top.index
                   );
 # ifdef SEPA
         for (u_int32_t i = 0; (c = (mular_getix(r2->imd, i))); ++i) {
             if  (((*c)->argc > 2) && ((*c)->argv) && ((*c)->argv[2])) {
-                fprintf(sto, "    char w%d[%u];\n", i, strlen((*c)->argv[2]) + 1);
-                ifBLIN_QX2("    char w%d[%u];", i, strlen((*c)->argv[2]) + 1);
+                fprintf(sto, "    char w%u[%"BLIN_U"];\n", i, strlen((*c)->argv[2]) + 1);
+                ifBLIN_QX2("    char w%u[%"BLIN_U"];", i, strlen((*c)->argv[2]) + 1);
             } else {
-                fprintf(sto, "    char w%d[1];\n", i);
-                ifBLIN_QX2("    char w%d[1];", i);
+                fprintf(sto, "    char w%u[1];\n", i);
+                ifBLIN_QX2("    char w%u[1];", i);
         }   }
 # else
         {   u_int32_t j = 0;
@@ -559,18 +566,12 @@ intrfil1(runparm *r, run12parm *r2) {
         fprintf(sto, "} e = \n");
         ifBLIN_QX2("} e =");
         if  (r2->inflag) {
-            fprintf(sto, "{(%s)", r2->inflag);
+            fprintf(sto, "{(%s),%u\n", r2->inflag, (u_int)r2->imd->top.index);
+            ifBLIN_QX2("{(%s),%u", r2->inflag, (u_int)r2->imd->top.index);
         } else {
-            fprintf(sto, "{0");
+            fprintf(sto, "{0,%u\n", (u_int)r2->imd->top.index);
+            ifBLIN_QX2("{0,%u", (u_int)r2->imd->top.index);
         }
-        ifBLIN_QO2 {
-            if  (r2->inflag) {
-                fprintf(stderr, "{(%s)", r2->inflag);
-            } else {
-                fprintf(stderr, "{0");
-        }   }
-        fprintf(sto, ",%u\n", (u_int)r2->imd->top.index);
-        ifBLIN_QX2(",%u", (u_int)r2->imd->top.index);
         if  (r2->intrans) {
             fprintf(sto, "#line %u \"%s\"\n,%s\n", (u_int)r2->lntrans, r2->infn, r2->intrans);
             ifBLIN_QX2("#line %u \"%s\"\n,%s", (u_int)r2->lntrans, r2->infn, r2->intrans);
@@ -661,15 +662,14 @@ run2cc(runparm *r, run12parm *r2) {
 # define blin_internal_flags (r->flags & BLIN_MASK)
     int   ex = EX_OK;
     int   status;
-    pid_t pid;
-    int   ex2;
 
     ifBLIN_QX4("+");
     if  (pipe(r2->pip2)) {
         ifBLIN_QW0("pipe #2");
         ex = EX_OSERR;
     } else {
-        ex2 = fork();
+        int ex2 = fork();
+
         ifBLIN_QX4("fork %d", ex2);
         if  (ex2 < 0) {
             ifBLIN_QW0("fork #2");
@@ -689,7 +689,7 @@ run2cc(runparm *r, run12parm *r2) {
                 ifBLIN_QO2 {
                     for (int g = 0; !!r2->ccarg[g]; ++g) ifBLIN_QX2("[%d]=%s~", g, r2->ccarg[g]);
                 }
-                execvp(r2->ccname, r2->ccarg);
+                execvp(r2->ccname, (char * const*)r2->ccarg);
                 ifBLIN_QW0("exec cc=%s~ fail", r2->ccname);
                 ex = EX_UNAVAILABLE;
             }
@@ -704,6 +704,8 @@ run2cc(runparm *r, run12parm *r2) {
             ifBLIN_QW0("pipe mife");
             ex = EX_NOINPUT;
         } else {
+            pid_t pid;
+
             mular_destroy(r2->imd);
             mife_fini(r->iffed);
             if  (!(r->iffed = mife_init(0))) {
@@ -715,8 +717,8 @@ run2cc(runparm *r, run12parm *r2) {
             } else if (((r->ccl = mife_read(r->iffed, 0, 0))) < 0) {
                 ifBLIN_QW0("pipe mife read");
                 ex = EX_IOERR;
-            } else if ((pid = wait6(P_PID, ex2, &status, WEXITED, NULL, NULL)) < 0) {
-                ifBLIN_QW0("wait6");
+            } else if ((pid = waitpid(ex2, &status, 0)) < 0) {
+                ifBLIN_QW0("waitpid");
                 ex = EX_TEMPFAIL;
             } else if (pid != ex2) {
                 ifBLIN_QW0("wait pid");
@@ -1157,9 +1159,7 @@ run4(runparm *r, ccbin *ls, tree *tree) {
         ex = EX_SOFTWARE;
     }
     ifBLIN_QX1("MAXW=%d MAXT=%d MAXINDX=%d SIZE=%d\n", (int)ls->maxw, (int)ls->t, (int)ls->maxl, ls->p);
-    fprintf(ls->o, ",%d", (int)ls->maxl);
-    fprintf(ls->o, ",%d", (int)ls->t);
-    fprintf(ls->o, ",%d\n", ls->p);
+    fprintf(ls->o, ",%d,%d,%d\n", (int)ls->maxl, (int)ls->t, ls->p);
     ifBLIN_QX4("- %d", ex);
     return(ex);
 # undef blin_internal_flags
@@ -1186,7 +1186,6 @@ run4out(runparm *r, ccbin *ls, tree *tree, treei j, ssize_t p) {
     int    f = 1;
     size_t n ;
     treei  i ;
-    treew  w ;
 
     if  (!j) {
         fprintf(ls->o, ",{");
@@ -1232,6 +1231,8 @@ run4out(runparm *r, ccbin *ls, tree *tree, treei j, ssize_t p) {
             fprintf(ls->o, rf[tf[TREE(v, i)]], TREE(v, i));
             ++p;
             if  (TRIS(TREE(d, i))) {
+                treew  w;
+
                 w = TREE(w, TREE(d, i)) - 2;
                 if  (ls->ibin->flags & Bpars_AABS) {
                     addrout(ls->o, (u_int32_t)ls->p, (u_int32_t)w);
@@ -1334,7 +1335,7 @@ main(int argc, char **argv) {
     if  (r2->incopy) fprintf(ls->o, "#line %u \"%s\"\n%s", (u_int)r2->lncopy, r2->infn, r2->incopy);
     if  (r2->intype) fprintf(ls->o, "#line %u \"%s\"\n%s ", (u_int)r2->lntype, r2->infn, r2->intype);
     fprintf(ls->o, "babolo_lexor %s = {\n", r2->inname);
-    fprintf( ls->o, "#line %u \"%s\"\n(u_char*)\n%s\n"
+    fprintf( ls->o, "#line %u \"%s\"\n(const u_char *)\n%s\n"
            , (u_int)r2->lntrans
            , r2->infn
            , r2->intrans ? r2->intrans : "NULL"
@@ -1387,10 +1388,8 @@ main(int argc, char **argv) {
         goto out;
     }
 out:
-    if  (!ex && !!(ex = fclose(ls->o))) {
-        ifBLIN_QW0("fclose");
-        ls->o = NULL;
-    }
+    if  (!ex && !!(ex = fclose(ls->o))) ifBLIN_QW0("fclose");
+    ls->o = NULL;
     if  (!!ls) {
         if  (!!ls->o) {
             fpurge(ls->o);
