@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2008..2024 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2008..2025 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +24,8 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2008..2024 @BABOLO http://www.babolo.ru/\n"
-#ident "@(#) $Id: getopt.c,v 1.32 2024/01/07 23:29:19 babolo Exp $\n"
+#ident "@(#) Copyright (C)2008..2025 @BABOLO http://www.babolo.ru/\n"
+#ident "@(#) $Id: getopt.c,v 1.39 2025/03/05 03:25:09 babolo Exp $\n"
 
 #define BLIN_COMPAT  4
 #define Bpars_COMPAT VMAJOR
@@ -38,7 +38,7 @@
 #include <errno.h>
 #include <err.h>
 #include <babolo/BLINflag.h>
-#include "parser.h"
+#include "../parser.h"
 
 #define ERROUT(A, B) do {errno = (B); ex = (A); goto out;} while (0)
 #define EXOUT(B)     do {errno = (B); goto out;} while (0)
@@ -95,7 +95,7 @@ optt(babolo_opt *bo, const char *ind) {
 static void
 optst(babolo_opts *bos, const char *ind) {
     fprintf( stderr
-           , "****s %"BLIN_X" %s %08X o=%c(%02X) r=%c(%02X) re=%u a=%u o=%s%s n%"BLIN_X" f%"BLIN_X"\n"
+           , "****s %"BLIN_X" %s %08X o=%c(%02X) r=%c(%02X) re=%d a=%d o=%s%s n%"BLIN_X" f%"BLIN_X"\n"
            , BLIN_I(bos)
            , ind
            , bos->flags
@@ -160,18 +160,21 @@ setopts(babolo_opts *bos, BLIN_flag flags, int argc, char **argv, const char *os
         ifBLIN_QX0("no argv");
         ERROUT(EX_DATAERR, EFAULT);
     }
-    for (j = 0; !!argv[j]; ++j) ifBLIN_QX5(" argv[%d]=%s~", j, argv[j]);
+    for (j = 0; j < argc; ++j) ifBLIN_QX5(" argv[%d]=%s~", j, argv[j]);
     next = bos->next;
     if  (!(bos->next = malloc(sizeof(babolo_opt)))) {
         ifBLIN_QX0("no mem #0");
         ERROUT(EX_OSERR, ENOMEM);
     }
     if  (bos->flags & Bpars_CMPT) {
-        bos->next->flags = flags & (BLIN_flag)~(Bpars_NPRM | Bpars_NOAL | Bpars_EOOP);
+        bos->next->flags = flags & ~(BLIN_flag)(Bpars_NPRM | Bpars_NOAL | Bpars_EOOP);
     } else {
         bos->next->flags = bos->flags & (BLIN_MASK | Bpars_EPRM | Bpars_ESYM);
         if  (!bp) bos->next->flags |= flags & (Bpars_FPTR | Bpars_FTXT | Bpars_NONU);
     }
+    if  (!!bp) {
+        bos->next->flags |= flags & Bpars_OWBP; // XXXX     
+    }
     bos->next->next = next;
     bos->next->argc = argc;
     bos->next->argv = argv;
@@ -327,7 +330,7 @@ closeopt(babolo_opt *opt) {
             for (i = 0; i < opt->argc; --i) free(opt->argv[i]);
         }
         if  (opt->flags & Bpars_FPTR) free(opt->argv);
-        if  (opt->bp) babolo_freeparm(opt->bp);
+        if  (opt->bp && (opt->flags & Bpars_OWBP)) babolo_freeparm(opt->bp);
         nnext = opt->next;
 # undef blin_internal_flags
         free(opt);
@@ -421,8 +424,8 @@ int
 babolo_getopts(babolo_opts *bos) {                                                               /****
  *****************************************************************************************************
  *****************************************************************************************************/
-    int ex = 0;
     int argn;
+    int ex  = 0;
 
     if  (!bos) {
         ifBLIN_QX0("no bos");
@@ -493,21 +496,26 @@ babolo_getopts(babolo_opts *bos) {
         if  (bos->symr && ((bos->symr & 0xDF) == (ex & 0xDF))) {
             bos->argin = 1;
             if  (!getoptsarg(bos)) {
+                u_int32_t    mask;
                 babolo_parm *bp;
-                u_int32_t mask;
+                char        *cp = NULL;
 
                 mask = (bos->flags & BLIN_MASK) | Bpars_NONU;
                 if  ((bos->symr ^ ex) & 0x20 ) mask |= Bpars_NOEN;
-                if  (!(bp = babolo_getparm(mask, &(bos->o), "", 0))) {
+                if  (!(cp = strdup(bos->o))) {
+                    ifBLIN_QW0("strdup=%s~", bos->o);
+                    ex = -EX_OSERR;
+                } else if (!(bp = babolo_getparm(mask, &cp, "", 0))) {
                     ifBLIN_QX0("no parm=%s~", bos->o);
                     ex = -EX_USAGE;
-                } else if (babolo_setparm(bos, 0, bp, NULL)) {
+                } else if (babolo_setparm(bos, Bpars_OWBP, bp, NULL)) {
                     ifBLIN_QX0("no opts=%s~", bos->o);
                     ex = -EX_USAGE;
                 } else {
                     ex = 0;
                 }
                 bos->o = NULL;
+                /* if  (!!cp) free(cp); XXXX   */
     }   }   }
     ifBLIN_QX4(" getopt %02X=%c", ex, ex);
     if  ((ex < 0) || !bos->next) goto out;
@@ -568,7 +576,7 @@ babolo_getoptsarg(babolo_opts *bos) {
  *****************************************************************************************************
  *****************************************************************************************************/
     int         ex = EX_OK;
-    const char *c;
+    const char *c  ;
 
     c = NULL;
     if  (!bos) {
@@ -607,8 +615,8 @@ babolo_getoptunum(babolo_opts *bos, int base) {
  *****************************************************************************************************
  *****************************************************************************************************/
     unsigned long ex = 0;
-    char         *cc;
-    const char   *c;
+    char         *cc ;
+    const char   *c  ;
 
     if  (!bos) {
         ifBLIN_QX0("no bos");
@@ -637,8 +645,8 @@ babolo_getoptsnum(babolo_opts *bos, int base) {
  *****************************************************************************************************
  *****************************************************************************************************/
     long        ex = 0;
-    char       *cc;
-    const char *c;
+    char       *cc ;
+    const char *c  ;
 
     if  (!bos) {
         ifBLIN_QX0("no bos");
@@ -717,20 +725,24 @@ babolo_dumpopts(const babolo_opts *bos) {
  *****************************************************************************************************
  *****************************************************************************************************/
 #   define blin_internal_flags (bos->flags & BLIN_MASK)
-    int               ex = 0;
     const babolo_opt *opt;
-    int               i;
-    int               j;
+    int               ex = 0;
+    int               i  ;
+    int               j  ;
 
     fprintf(stderr, "common flags=%08X", bos->flags);
     if  (bos->flags & Bpars_SYMe) fprintf(stderr, " E=%c", bos->flags & Bpars_SYMe);
-    if  (bos->symr) fprintf(stderr, " Z=%c", bos->symr & 0xFF);
-    if  (bos->c) fprintf(stderr, " -%c", bos->c);
-    if  (bos->o) fprintf(stderr, "=%s~", bos->o);
+    if  (bos->symr)               fprintf(stderr, " Z=%c", bos->symr & 0xFF);
+    if  (bos->c)                  fprintf(stderr, " -%c", bos->c);
+    if  (bos->o)                  fprintf(stderr, "=%s~", bos->o);
     fprintf(stderr, " redirenv=%d argin=%d\n", bos->redirenv, bos->argin);
     for (i = 0, opt = bos->next; !!opt; ++i, opt = opt->next) {
         fprintf( stderr, "%3d %"BLIN_X" flags=%08X argc=%d ind=%d\n"
-               , i, BLIN_I(opt), opt->flags, opt->argc, opt->ind
+               , i
+               , BLIN_I(opt)
+               , opt->flags
+               , opt->argc
+               , opt->ind
                );
         if  (!!opt->opts) {
             fprintf(stderr, "opts 0123 4567 89AB CDEF\n");
@@ -750,7 +762,7 @@ babolo_dumpopts(const babolo_opts *bos) {
         if  (!!opt->arg) fprintf(stderr, "arg=%s~\n", opt->arg);
         if  (!!opt->plc) fprintf(stderr, "plc=%s~\n", opt->plc);
         if  (!!opt->argv) {
-            for (j = 0; !!opt->argv[j]; ++j) {
+            for (j = 0; j < opt->argc; ++j) {
                 fprintf(stderr, "%cargv[%d]=%s~\n", (j == opt->ind) ? '>' : ' ', j, opt->argv[j]);
     }   }   }
     ifBLIN_QX3("- %d", ex);
@@ -763,9 +775,10 @@ void
 babolo_optest(const char *ostr) {                                                                /****
  *****************************************************************************************************
  *****************************************************************************************************/
-    int i, c, s;
+    for (u_int i = 0; ostr[i];) {
+        u_int c;
+        u_int s;
 
-    for (i = 0; ostr[i];) {
         s = i++;
         for (c = 0; ostr[i] == ':'; ++i) if (c < 255) ++c;
         printf("%c\t%u\n", ostr[s], c);
