@@ -25,7 +25,7 @@
  */
 
 #ident "@(#) Copyright (C)2006..2024 @BABOLO http://www.babolo.ru/\n"
-#ident "@(#) $Id: getord.c,v 1.25 2024/01/07 23:29:19 babolo Exp $\n"
+#ident "@(#) $Id: getord.c,v 1.26 2024/01/14 18:18:05 babolo Exp $\n"
 
 #define BLIN_COMPAT  4
 #define MIFE_COMPAT  5
@@ -38,7 +38,7 @@
 #include <stdio.h>
 #include <babolo/BLINflag.h>
 #include <mife.h>
-#include "parser.h"
+#include "../parser.h"
 
 static u_int32_t ofm[] = {0x00000000, 0x000000FF, 0x0000FFFF, 0x00FFFFFF, 0xFFFFFFFF};
 
@@ -89,15 +89,16 @@ babolo_testchar(const babolo_lexor *lext, u_int32_t state, const char **next) {
  *****************************************************************************************************/
 # define blin_internal_flags (lext->flags & BLIN_MASK)
     size_t lexind;                         /*      (  )        */
-    int    found ;                         /*                        */
     u_char nxch  ;                         /* , , ,    */
     size_t e     = (size_t)~0;             /*                                               */
-    size_t n     ;                         /*               */
-    u_char c     ;                         /*                                   */
 
     ifBLIN_QX3("+ flags=%06X state=%d next=%02X(%c)", lext->flags, state, **next & 0xFF, **next);
     nxch = (lext->retable) ? lext->retable[**next & 0xFF] : **next & 0xFF;
     if  (state < lext->szt) {                                         /* state    lext */
+        int    found;                      /*                        */
+        size_t n    ;                      /*               */
+        u_char c    ;                      /*                                   */
+
         lexind = (lext->szp + 1) * state;             /*        */
         found = 0;
         for (n = lext->lexgraf[lexind++] + 1; n > 0; --n) {          /*      */
@@ -139,10 +140,11 @@ babolo_weakchar(const babolo_lexor *lext, u_int32_t state) {
 # define blin_internal_flags (lext->flags & BLIN_MASK)
     size_t lexind = 0;
     size_t e      = (size_t)~0;
-    size_t n;
 
     ifBLIN_QX3("+ flags=%06X state=%d", lext->flags, state);
     if  (state < lext->szt) {                                         /* state    lext */
+        size_t n;
+
         lexind = (lext->szp + 1) * state;
         n = lext->lexgraf[lexind++] + 1;
         lexind += (lext->szp + 1) * n;
@@ -327,12 +329,13 @@ babolo_treedump(const babolo_lexor *lext) {
     u_int32_t k;
     u_int32_t m;
     u_int32_t e;
-    u_int32_t n;
 
     m = 0;
     lexind = 0;
     k = 0;
     for (;;) {
+        u_int32_t n;
+
         n = lext->lexgraf[lexind++] + 1;
         fprintf(stderr, "[%2u]", k);
         for (j = 0; j < n; ++j) {
