@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2003..2024 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2003..2025 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,12 +24,13 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2003..2024 @BABOLO http://www.babolo.ru/\n"
-#ident "@(#) $Id: getparm.c,v 1.39 2024/01/07 23:27:18 babolo Exp $\n"
+#ident "@(#) Copyright (C)2003..2025 @BABOLO http://www.babolo.ru/\n"
+#ident "@(#) $Id: getparm.c,v 1.43 2025/03/03 21:15:34 cuhegh Exp $\n"
 
 #define BLIN_COMPAT  4
 #define Bpars_COMPAT VMAJOR
 
+#include <sys/param.h>
 #include <sys/cdefs.h>
 #include <sys/types.h>
 #include <sysexits.h>
@@ -40,7 +41,7 @@
 #include <stdio.h>
 #include <err.h>
 #include <babolo/BLINflag.h>
-#include "parser.h"
+#include "../parser.h"
 
 #define Ca 0x00800000 /*              */
 #define Cr 0x00400000 /*                       */
@@ -332,9 +333,10 @@ static babolo_parm *
 /*****************************************************************************************************/
 i_getparm(getparm *parm) {                                                                       /****
  *****************************************************************************************************/
+#   define blin_internal_flags (parm->flags & BLIN_MASK)
     u_int32_t     control = 0;
     u_int16_t     regsym  = 0;
-    u_char       *regvar  = NULL;
+    const u_char *regvar  = NULL;
     babolo_parm  *parsed  = NULL;
     int           ixvar;                                        /*    (0 .. 3) */
     enum states   state;
@@ -344,7 +346,6 @@ i_getparm(getparm *parm) {
     u_char       *q;
     size_t        l;
 
-#   define blin_internal_flags (parm->flags & BLIN_MASK)
     ifBLIN_QX3( "+ flags=%08X absq=%02X test=%u end=%s~"
               , parm->flags
               , parm->absq
@@ -404,10 +405,13 @@ i_getparm(getparm *parm) {
                 ++t;
         }   }
         if  (control & Cw) {
-            int i, j;
-            u_char *c, *d;
+            int i;
 
             for (i = 0; environ && environ[i]; ++i) {
+                int           j;
+                u_char       *c;
+                const u_char *d;
+
                 for ( c = environ[i], d = regvar, j = 1
                     ; (*c != '=') && !!*c && !!*d && (d < q) && (*c == *d)
                     ; ++c, ++d
@@ -476,7 +480,7 @@ i_getparm(getparm *parm) {
             control |= Cx;
         }
         if  (control & Cx) {
-            if  ((~parm->flags & Bpars_NONU) && parsed) parsed->argv[parm->nidx] = NULL;
+            if  (!(parm->flags & Bpars_NONU) && parsed) parsed->argv[parm->nidx] = NULL;
             control = dx;
         }
         state = control & C_state;
@@ -563,11 +567,11 @@ babolo_dumparm(babolo_parm *parsed) {
  *****************************************************************************************************
  *****************************************************************************************************/
 #   define blin_internal_flags (parsed->flags & BLIN_MASK)
-    int i;
-
     printf("###########################################\n");
     printf("Parm @%" BLIN_X ":", BLIN_I(parsed));
     if  (parsed) {
+        int i;
+
         blin_64(parsed->flags, nm, -24, stdout);
         printf(" NPRM=%u\n", parsed->flags & Bpars_NPRM);
         printf( "  argc=%d, cntr=%" BLIN_U ", argv=%" BLIN_X "\n"
